==> 10.0.0-dev.1.tar.gz: lib/network/shake_http_logger.dart <==
import 'dart:io';

import 'package:shake_flutter/models/network_request.dart';
import 'package:shake_flutter/shake_flutter.dart';
import 'package:shake_flutter/utils/extensions.dart';

class ShakeHttpLogger {
  Map<int, NetworkRequest> requests = <int, NetworkRequest>{};

  void onRequest(
    HttpClientRequest request, {
    String requestBody,
  }) {
    final NetworkRequest networkRequest = NetworkRequest();
    networkRequest.startTime = DateTime.now();
    networkRequest.method = request.method;
    networkRequest.url = request.uri.toString();

    if (requestBody != null) {
      if (requestBody.isBinary()) {
        networkRequest.requestBody = "Binary data";
      } else {
        networkRequest.requestBody = requestBody;
      }
    }

    request.headers.forEach((String header, dynamic value) {
      networkRequest.requestHeaders[header] = value[0].toString();
    });

    requests[request.hashCode] = networkRequest;
  }

  void onResponse(
    HttpClientResponse response,
    HttpClientRequest request, {
    String responseBody,
  }) {
    final NetworkRequest networkRequest = _getRequestData(request.hashCode);
    if (networkRequest == null) {
      return null;
    }

    networkRequest.endTime = DateTime.now();
    networkRequest.status = response.statusCode;

    if (responseBody != null) {
      if (responseBody.isBinary()) {
        networkRequest.responseBody = "Binary data";
      } else {
        networkRequest.responseBody = responseBody;
      }
    }

    response.headers.forEach((String header, dynamic value) {
      networkRequest.responseHeaders[header] = value[0].toString();
    });

    Shake.insertNetworkRequest(networkRequest);
  }

  NetworkRequest _getRequestData(int requestHashCode) {
    if (requests[requestHashCode] != null) {
      return requests.remove(requestHashCode);
    }
    return null;
  }
}

==> 14.1.1.tar.gz: lib/network/shake_http_logger.dart <==
import 'dart:io';

import 'package:shake_flutter/models/network_request.dart';
import 'package:shake_flutter/shake_flutter.dart';
import 'package:shake_flutter/utils/extensions.dart';

/// Parser and logger for dart:io network requests.
class ShakeHttpLogger {
  Map<int, NetworkRequest> _requests = <int, NetworkRequest>{};

  void onRequest(
    HttpClientRequest request, {
    String requestBody,
  }) {
    final NetworkRequest networkRequest = NetworkRequest();
    networkRequest.startTime = DateTime.now();
    networkRequest.method = request.method;
    networkRequest.url = request.uri.toString();
    networkRequest.requestBody = _removeBinaryData(requestBody);
    request.headers.forEach((String header, dynamic value) {
      networkRequest.requestHeaders[header] = value[0].toString();
    });

    _requests[request.hashCode] = networkRequest;
  }

  void onResponse(
    HttpClientRequest request,
    HttpClientResponse response, {
    String responseBody,
  }) async {
    final NetworkRequest networkRequest = _getRequestData(request.hashCode);
    if (networkRequest == null) {
      return null;
    }

    networkRequest.endTime = DateTime.now();
    networkRequest.status = response.statusCode.toString();
    networkRequest.responseBody = _removeBinaryData(responseBody);
    response.headers.forEach((String header, dynamic value) {
      networkRequest.responseHeaders[header] = value[0].toString();
    });

    Shake.insertNetworkRequest(networkRequest);
  }

  String _removeBinaryData(String text) {
    if (text == null) return "";

    if (text.isBinary()) {
      return "Binary data";
    }

    return text;
  }

  NetworkRequest _getRequestData(int requestHashCode) {
    if (_requests[requestHashCode] != null) {
      return _requests.remove(requestHashCode);
    }
    return null;
  }
}
